#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                7.2.7
visibility:             public
id:                     taffybar-7.2.7-4fXO17Q3FKrLaRt47qjr95
key:                    taffybar-7.2.7-4fXO17Q3FKrLaRt47qjr95
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               https://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
description:
    Taffybar is a desktop status bar with GTK widgets for window
    manager state, system information, tray icons, and custom user modules.

category:               System
abi:                    37d47199a146477e0e21ed69462f93d8
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.Context.Backend System.Taffybar.DBus
    System.Taffybar.DBus.Toggle System.Taffybar.Example
    System.Taffybar.Hooks System.Taffybar.Hyprland
    System.Taffybar.Information.ASUS
    System.Taffybar.Information.AnthropicUsage
    System.Taffybar.Information.Audio
    System.Taffybar.Information.Backlight
    System.Taffybar.Information.Battery
    System.Taffybar.Information.Bluetooth
    System.Taffybar.Information.CPU2
    System.Taffybar.Information.CPUFrequency
    System.Taffybar.Information.ChromeWindowInfo
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.DiskUsage
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.Hyprland
    System.Taffybar.Information.HyprlandWorkspaceHistory
    System.Taffybar.Information.Inhibitor
    System.Taffybar.Information.KeyboardState
    System.Taffybar.Information.Layout.EWMH
    System.Taffybar.Information.Layout.Hyprland
    System.Taffybar.Information.Layout.Model
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.NetworkManager
    System.Taffybar.Information.Nvidia
    System.Taffybar.Information.OpenAIUsage
    System.Taffybar.Information.PowerProfiles
    System.Taffybar.Information.Privacy
    System.Taffybar.Information.PulseAudio
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.ScreenLock
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.Systemd
    System.Taffybar.Information.Temperature
    System.Taffybar.Information.Wakeup
    System.Taffybar.Information.WirePlumber
    System.Taffybar.Information.Wlsunset
    System.Taffybar.Information.Workspaces.EWMH
    System.Taffybar.Information.Workspaces.Hyprland
    System.Taffybar.Information.Workspaces.Model
    System.Taffybar.Information.Workspaces.Refresh
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.LogLevels
    System.Taffybar.SimpleConfig System.Taffybar.Support.PagerHints
    System.Taffybar.Util System.Taffybar.Widget
    System.Taffybar.Widget.ASUS System.Taffybar.Widget.AnthropicUsage
    System.Taffybar.Widget.Audio System.Taffybar.Widget.Backlight
    System.Taffybar.Widget.Battery System.Taffybar.Widget.BatteryDonut
    System.Taffybar.Widget.BatteryTextIcon
    System.Taffybar.Widget.Bluetooth
    System.Taffybar.Widget.CPUFrequency
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner
    System.Taffybar.Widget.CoordinatedClock
    System.Taffybar.Widget.Crypto System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.DiskUsage System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoFillImage
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.ScalingImage
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.HyprlandLayout
    System.Taffybar.Widget.ImageCommandButton
    System.Taffybar.Widget.Inhibitor
    System.Taffybar.Widget.KeyboardState System.Taffybar.Widget.Layout
    System.Taffybar.Widget.MPRIS2 System.Taffybar.Widget.NetworkGraph
    System.Taffybar.Widget.NetworkManager
    System.Taffybar.Widget.NvidiaTemperature
    System.Taffybar.Widget.OmniMenu System.Taffybar.Widget.OpenAIUsage
    System.Taffybar.Widget.PowerProfiles System.Taffybar.Widget.Privacy
    System.Taffybar.Widget.PulseAudio System.Taffybar.Widget.SNIMenu
    System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SNITray.PrioritizedCollapsible
    System.Taffybar.Widget.ScreenLock
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Systemd System.Taffybar.Widget.Temperature
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.WakeupDebug
    System.Taffybar.Widget.Weather System.Taffybar.Widget.Windows
    System.Taffybar.Widget.WirePlumber System.Taffybar.Widget.Wlsunset
    System.Taffybar.Widget.Workspaces System.Taffybar.Widget.WttrIn
    System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WidgetPriority System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.ChromeWindowInfo
    System.Taffybar.DBus.Client.Login1Manager
    System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.NetworkManager
    System.Taffybar.DBus.Client.NetworkManagerAccessPoint
    System.Taffybar.DBus.Client.NetworkManagerActiveConnection
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.PulseAudioCore
    System.Taffybar.DBus.Client.PulseAudioDevice
    System.Taffybar.DBus.Client.PulseAudioServerLookup
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util
    System.Taffybar.Information.Hyprland.API
    System.Taffybar.Information.Hyprland.Types
    System.Taffybar.Information.Workspaces.Support
    System.Taffybar.Information.Wakeup.Manager
    System.Taffybar.Information.Udev
    System.Taffybar.Window.FocusedMonitor

import-dirs:            /usr/lib/ghc-9.6.6/site-local/taffybar-7.2.7
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/taffybar-7.2.7 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/taffybar-7.2.7 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-7.2.7-4fXO17Q3FKrLaRt47qjr95
extra-libraries:
    gtk-3 gdk-3 pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0 z udev

extra-libraries-static:
    gtk-3 gdk-3 pangocairo-1.0 Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 m pthread atk-bridge-2.0 atspi Xtst Xi
    Xfixes atk-1.0 dbus-1 xkbcommon wayland-cursor wayland-egl
    wayland-client m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m
    fribidi thai datrie Xft cairo m dl fontconfig m expat m Xext
    Xrender X11 pthread xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m
    harfbuzz-gobject harfbuzz m freetype dl bz2 png16 m m brotlidec
    brotlicommon graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    atomic m pcre2-8 pthread z mount blkid systemd sysprof-capture-4
    udev

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-IAaVZRSfZqwFVkbWmGYd3g
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z
    ansi-terminal-1.1-FMAjddYCnoo35p0Ajg6Jk8 base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-A5CFvWaedHyBbFpBELr7ED
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    dbus-1.3.3-3w5RglogPnh9ZBTlozw1TD
    dbus-hslogger-0.1.1.1-keW1EgoC6eIn7dQrUoHxe
    dbus-menu-0.1.3.4-7ElLdprrWSCF9cfi9DXLjL directory-1.3.8.5
    disk-free-space-0.1.0.1-EM7dsETQ4QyF5Xspy0kIXr
    dyre-0.9.2-7Le4jOC75atJ5aaluPymeQ
    either-5.0.3-FO5G0a5Qhco7sKJnDvQml6
    enclosed-exceptions-1.0.3-Agpnn0IUHUaKvKpNK5TCe0 filepath-1.4.300.1
    fsnotify-0.4.4.0-CeEazFCobkJF9t8pqOUlX
    gi-cairo-connector-0.1.1-7uynRCW1y2u1dK0uiof2Id
    gi-cairo-render-0.1.2-Kj3foQkl9TH1rrXqbiLLy2
    gi-gdk3-3.0.30-FYr0miE6cDgBeWfFoLEvjy
    gi-gdkpixbuf-2.0.32-HF29aMfV073CJREslGoIfr
    gi-gdkx113-3.0.17-8jcepxsqsUTExKur1zdTwn
    gi-glib-2.0.30-3iln1JWNe3fBbTIJi5vYeO
    gi-gobject-2.0.31-DolhjsSRQwl7P2igTzs7Mo
    gi-gtk-hs-0.3.18-5sTXpYBS8gTHRQbL6ZRAy6
    gi-gtk-layer-shell-0.1.7-CCoH2oCMVdzKbiA0saJWJf
    gi-gtk3-3.0.44-309fzdC4rCB3CsRHzS3G5F
    gi-pango-1.0.30-3BWSH1C423bJKKspF3PwA7
    gi-wireplumber-0.5.14.2-AG1gJ1AZKFHDE2df5d0pL5
    gtk-scaling-image-0.1.0.1-2DbULfgEkliCFoEys0gOFu
    gtk-sni-tray-0.2.1.4-2JKpAivLbAN9WoRHT57o2t
    gtk-strut-0.1.4.1-Cr4zajvg2fl2B2zLNylpdg
    haskell-gi-base-0.26.9-A51M6LjdiVN4RjdHJdLeji
    hslogger-1.3.2.0-D93Y2qjH7EfINBYoIXbCKD
    http-client-0.7.19-JFk9tUfcyF3FnWNRzLmEjW
    http-client-tls-0.3.6.4-Dj2m0zumhuN7HSttI52C5a
    http-conduit-2.3.9.1-7x31A8Bvf12J6SDKAlTcxw
    http-types-0.12.4-FjxwRmZWhoR3wzry1r4T66
    monad-control-1.0.3.1-JD20Nk0MZISXRupR36zqX
    multimap-1.2.1-4W8aWHvVl9g78Tpaptjwyw
    network-3.1.4.0-9nB9sbnLDjyBVIWLW7TDGb parsec-3.1.16.1
    process-1.6.19.0 rate-limit-1.4.3-6ydvOkN3EwQLZ5xS3sVlHp
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag
    safe-0.3.21-BwgmeaVWtgPGRp7BdJoWxU
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl
    status-notifier-item-0.3.2.16-8phlTifO99lK0KJ7bBpX4R stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    time-units-1.0.0-5DRkw9RXZDICp7PYN09sTv transformers-0.6.1.0
    tuple-0.3.0.2-C7fFum5jKrcGqYEc1JEkBP unix-2.8.4.0
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    xdg-basedir-0.2.2-DLaKUfv1JJAFBfkP0BUklH
    xdg-desktop-entry-0.1.1.5-J0mXMRe427U55Oz7UxW7tY
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-helpers-1.0.0-4qhWXJoUbtX94cToL5WE9g
    xmonad-0.18.1-BVbTV5SDipB7ZpqV5sccti
    yaml-0.11.11.2-LUugXbkeJApKC0qW2gmxvA

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-taffybar-z-testlib
version:              7.2.7
package-name:         taffybar
lib-name:             testlib
id:                   taffybar-7.2.7-7CsqOoRkZRuJgg6GhSC9Sa-testlib
key:                  taffybar-7.2.7-7CsqOoRkZRuJgg6GhSC9Sa-testlib
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/taffybar/taffybar
synopsis:             A desktop bar similar to xmobar, but with more GUI
description:
    Taffybar is a desktop status bar with GTK widgets for window
    manager state, system information, tray icons, and custom user modules.

category:             System
abi:                  c7b927cb97d56d7ddc7afb0a1697bfa9
exposed-modules:
    System.Taffybar.Test.DBusSpec System.Taffybar.Test.UtilSpec
    System.Taffybar.Test.XvfbSpec TestLibSpec

import-dirs:          /usr/lib/ghc-9.6.6/site-local/taffybar-7.2.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/taffybar-7.2.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/taffybar-7.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/taffybar
hs-libraries:         HStaffybar-7.2.7-7CsqOoRkZRuJgg6GhSC9Sa-testlib
depends:
    QuickCheck-2.15.0.1-HW6HIMYjXnYB7OQUyImYOa
    attoparsec-0.14.4-8xTfRBafHfnLSxW1Zd3VTX base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    dbus-1.3.3-3w5RglogPnh9ZBTlozw1TD
    extra-1.7.16-aWEq6cZZ289lIc6yxljo5 filepath-1.4.300.1
    hslogger-1.3.2.0-D93Y2qjH7EfINBYoIXbCKD
    hspec-2.11.7-IufmvTkKFuhK8Sz3dfXkFn
    taffybar-7.2.7-4fXO17Q3FKrLaRt47qjr95 text-2.0.2
    typed-process-0.2.13.0-3fEd93V0TXmE2z8JtzQYbJ unix-2.8.4.0
    unliftio-0.2.25.1-95hsWJFispi2AzgK8xFJw
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:         /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

